Module async_transports

Module async_transports 

Structs

PollingTransport
An asynchronous polling type. Makes use of the nonblocking reqwest types and methods.
WebsocketSecureTransport
An asynchronous websocket transport type. This type only allows for secure websocket connections (“wss://”).
WebsocketTransport
An asynchronous websocket transport type. This type only allows for plain websocket connections (“ws://”).