Module client

Module client 

Structs

Client
An engine.io client that allows interaction with the connected engine.io server. This client provides means for connecting, disconnecting and sending packets to the server.
ClientBuilder
Iter
SocketIter