pub struct ClientBuilder { /* private fields */ }Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
pub fn new(url: Url) -> Self
Sourcepub fn tls_config(self, tls_config: TlsConnector) -> Self
pub fn tls_config(self, tls_config: TlsConnector) -> Self
Specify transport’s tls config
Sourcepub fn build(self) -> Result<Client, Error>
pub fn build(self) -> Result<Client, Error>
Build websocket if allowed, if not fall back to polling
Sourcepub fn build_polling(self) -> Result<Client, Error>
pub fn build_polling(self) -> Result<Client, Error>
Build socket with polling transport
Sourcepub fn build_websocket_with_upgrade(self) -> Result<Client, Error>
pub fn build_websocket_with_upgrade(self) -> Result<Client, Error>
Build socket with a polling transport then upgrade to websocket transport
Sourcepub fn build_websocket(self) -> Result<Client, Error>
pub fn build_websocket(self) -> Result<Client, Error>
Build socket with only a websocket transport
Sourcepub fn build_with_fallback(self) -> Result<Client, Error>
pub fn build_with_fallback(self) -> Result<Client, Error>
Build websocket if allowed, if not allowed or errored fall back to polling. WARNING: websocket errors suppressed, no indication of websocket success or failure.