Structs
- Polling
Transport - An asynchronous polling type. Makes use of the nonblocking reqwest types and methods.
- Websocket
Secure Transport - An asynchronous websocket transport type. This type only allows for secure websocket connections (“wss://”).
- Websocket
Transport - An asynchronous websocket transport type. This type only allows for plain websocket connections (“ws://”).